==> nextcloud-20.0.13.tgz: nextcloud/apps/weather_status/l10n/ca.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Adreça desconeguda",
    "No result." : "No hi ha resultats.",
    "Malformed JSON data." : "Les dades en format JSON estan mal formades.",
    "Error" : "Error",
    "Weather status" : "Estat del temps",
    "Weather status in your dashboard" : "Estat del temps al tauler",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Estat del temps integrat a l'aplicació Tauler.\n    La posició de l'usuari es pot determinar o definir manualment automàticament. A continuació, es mostra una previsió de 6 hores.\n    Aquest estat també es pot integrar en altres llocs, com ara l'aplicació de Calendari.",
    "Detect location" : "Detecta la ubicació",
    "Set custom address" : "Defineix una adreça personalitzada",
    "Favorites" : "Preferits",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Cel clar a les {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Ennuvolat a les {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Bon dia a les {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Bona nit a les {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Parcialment ennuvolat a les {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Boira a les {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Plugim a les {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Pluja a les {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Pluja intensa a les {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Ruixats a les {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Ruixats lleugers a les {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Ruixats intensos a les {time}",
    "More weather for {adr}" : "Més temps per a {adr}",
    "Loading weather" : "S'està carregant el temps",
    "Set location for weather" : "Definir la ubicació per al temps",
    "Remove from favorites" : "Suprimeix dels preferits",
    "Add as favorite" : "Afegeix-ho com a preferit",
    "You are not logged in." : "No heu iniciat la sessió.",
    "There was an error getting the weather status information." : "S'ha produït un error en obtenir la informació de l'estat del temps.",
    "No weather information found" : "No s'ha trobat informació del temps",
    "Location not found" : "No s'ha trobat la ubicació",
    "There was an error setting the location address." : "S'ha produït un error en definir l'adreça de la ubicació.",
    "There was an error setting the location." : "S'ha produït un error en definir la ubicació.",
    "There was an error saving the mode." : "S'ha produït un error en desar el mode.",
    "There was an error using personal address." : "S'ha produït un error en utilitzar l'adreça personal.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Estat del temps integrat a l'aplicació tauler.\n    La posició de l'usuari es pot determinar o definir manualment automàticament. A continuació, es mostra una previsió de 6 hores.\n    Aquest estat també es pot integrar en altres llocs, com ara l'aplicació de Calendari."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.0p0.tgz: nextcloud/apps/weather_status/l10n/ca.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Adreça desconeguda",
    "No result." : "No hi ha resultats.",
    "Malformed JSON data." : "Dades de JSON mal formades.",
    "Error" : "Error",
    "Weather status" : "Estat del temps",
    "Weather status in your dashboard" : "Estat del temps al seu tauler",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Estat del temps integrat a l'aplicació Tauler.\n    La posició de l'usuari es pot determinar o definir manualment automàticament. A continuació, es mostra una previsió de 6 hores.\n    Aquest estat també es pot integrar en altres llocs, com ara l'aplicació de Calendari.",
    "Detect location" : "Detecta la ubicació",
    "Set custom address" : "Definir l'adreça personalitzada",
    "Favorites" : "Favorits",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Cel clar a les {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Ennuvolat a les {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Bon dia a les {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Bona nit a les {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Parcialment ennuvolat a les {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Boira a les {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Pluja lleugera a les {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Pluja a les {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Pluja intensa a les {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Aiguat a les {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Ruixats lleugers a les {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Ruixats intensos a les {time}",
    "More weather for {adr}" : "Més temps per a {adr}",
    "Loading weather" : "S' està carregant el temps",
    "Set location for weather" : "Definir la ubicació per al temps",
    "Remove from favorites" : "Suprimeix de preferits",
    "Add as favorite" : "Afegeix-ho com a preferit",
    "You are not logged in." : "No heu iniciat la sessió.",
    "There was an error getting the weather status information." : "S'ha produït un error en obtenir la informació de l'estat del temps.",
    "No weather information found" : "No s'ha trobat informació meteorològica",
    "Location not found" : "No s'ha trobat la ubicació",
    "There was an error setting the location address." : "S'ha produït un error en definir l'adreça d'ubicació.",
    "There was an error setting the location." : "S'ha produït un error en definir la ubicació.",
    "There was an error saving the mode." : "S'ha produït un error en desar el mode.",
    "There was an error using personal address." : "S'ha produït un error en utilitzar l'adreça personal.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Estat del temps integrat a l'aplicació tauler.\n    La posició de l'usuari es pot determinar o definir manualment automàticament. A continuació, es mostra una previsió de 6 hores.\n    Aquest estat també es pot integrar en altres llocs, com ara l'aplicació de Calendari."
},
"nplurals=2; plural=(n != 1);");
